@@ -36,7 +36,11 @@ main (argc,argv)
   if (argc == 2 && strcmp (argv[1], "-alt") == 0
       && var_l1 + var_l2 + var_l4 == 8)
 	return 0;
+  printf("var_l1(%d) + var_l2(%d) + var_l4(%d) == %d\n",var_l1,var_l2,var_l4, var_l1 + var_l2 + var_l4);
   if (var_l1 + var_l2 + var_l4 != 20)
+	{
+	printf("var_l1(%d) + var_l2(%d) + var_l4(%d) != 20\n",var_l1,var_l2,var_l4);
   	return 1;
+	}
   return 0;
 }
